@@ -1,4 +1,4 @@
-<?
+<?php
 /************************************************************************
 UebiMiau is a GPL'ed software developed by 
 
@@ -7,6 +7,14 @@ UebiMiau is a GPL'ed software developed by
 
 Fell free to contact, send donations or anything to me :-)
 So Paulo - Brasil
+
+**********************************************
+
+Recoded to UebiMiau Version 3.0 by Dave Rodgers 
+Dec 2006
+http://www.manvel.net
+Email: Davenmanvel@inbox.com
+Feel free to contact me, send donations or anything to me as well...
 *************************************************************************/
 
 
@@ -41,9 +49,9 @@ fclose($fp);
 $disposition = (!$down)?"inline":"attachment";
 $type = (!preg_match("/[a-z]+\/[a-z-]+/i",$attach["content-type"]))?"application/octet-stream":$attach["content-type"];
 
-Header("Content-Type: $type; name=\"".$attach["name"]."\"");
-Header("Content-Length: $size");
-Header("Content-Disposition: $disposition; filename=\"".$attach["name"]."\"");
+Header("Content-Type: $type; name=\"".$attach["name"]."\"\r\n");
+Header("Content-Length: $size\r\n");
+Header("Content-Disposition: $disposition; filename=\"".$attach["name"]."\"\r\n");
 
 echo($stream);
-?>
+?>
\ No newline at end of file
