@@ -1,4 +1,4 @@
-<?
+<?php
 $folders = $sess["folders"];
 $scounter = 0;
 $pcounter = 0;
@@ -16,6 +16,9 @@ foreach($folders as $entry) {
 		case strtolower($sess["sysmap"]["trash"]):
 			$boxname = $trash_extended;
 			break;
+		case strtolower($sess["sysmap"]["spam"]):
+			$boxname = $spam_extended;
+			break;
 		}
 		$system[$scounter]["systemname"]    = $entry;
 		$system[$scounter]["name"]      	= $boxname;
