@@ -1,12 +1,17 @@
-<?
+<?php
 /************************************************************************
 UebiMiau is a GPL'ed software developed by 
 
  - Aldoir Ventura - aldoir@users.sourceforge.net
  - http://uebimiau.sourceforge.net
 
-Fell free to contact, send donations or anything to me :-)
-So Paulo - Brasil
+**********************************************
+
+Recoded to UebiMiau Version 3.0 by Dave Rodgers 
+Dec 2006
+http://www.manvel.net
+Email: Davenmanvel@inbox.com
+Feel free to contact me, send donations or anything to me as well...
 *************************************************************************/
 require("./inc/inc.php");
 if(!isset($folder) || !isset($ix)) die("Expected parameters");
