@@ -1,4 +1,4 @@
-<?
+<?php
 /************************************************************************
 UebiMiau is a GPL'ed software developed by 
 
@@ -7,6 +7,14 @@ UebiMiau is a GPL'ed software developed by
 
 Fell free to contact, send donations or anything to me :-)
 So Paulo - Brasil
+**********************************************
+
+Recoded to UebiMiau Version 3.0 by Dave Rodgers 
+Dec 2006
+http://www.manvel.net
+Email: Davenmanvel@inbox.com
+Feel free to contact me, send donations or anything to me as well...
+
 *************************************************************************/
 
 
@@ -214,29 +222,39 @@ class UebiMiau_core {
 	$decodedheaders["subject"] = "Hi";
 	
 	Some headers are broken into multiples lines, prefixed with a TAB (\t)
-	*/
+*/
 	function decode_header($header) {
 		$headers = explode("\r\n",$header);
 		$decodedheaders = Array();
 		for($i=0;$i<count($headers);$i++) {
-			$thisheader = trim($headers[$i]);
-			if(!empty($thisheader))
-				if(!ereg("^[A-Z0-9a-z_-]+:",$thisheader))
-					$decodedheaders[$lasthead] .= " ".$thisheader;
-				else {
+			
+			// If current header starts with a TAB or is not very standard, 
+			// attach it at the prev header			
+			if(($headers[$i]{0} == "\t") || !ereg("^[A-Z0-9a-z_-]+:",trim($headers[$i])) ) {
+				$decodedheaders[$lasthead] .= " ".trim($headers[$i]);
+			}
+			else { // otherwise extract the header
+				$thisheader = trim($headers[$i]);
+				if(!empty($thisheader)) {			 	
 					$dbpoint = strpos($thisheader,":");
 					$headname = strtolower(substr($thisheader,0,$dbpoint));
 					$headvalue = trim(substr($thisheader,$dbpoint+1));
-					if(array_key_exists($headname, $decodedheaders)) $decodedheaders[$headname] .= "; $headvalue";
-					else $decodedheaders[$headname] = $headvalue;
-					$lasthead = $headname;
+					if(array_key_exists($headname, $decodedheaders))
+						$decodedheaders[$headname] .= "; $headvalue";
+					else 
+						$decodedheaders[$headname] = $headvalue;
+					$lasthead = $headname;										
 				}
-		}
+				unset($thisheader);
+			}
 
+		}
+		unset($headers);
 		return $decodedheaders;
 	}
 
 
+
 	/**
 	Try to extract all names in a specified field (from, to, cc)
 	In order to guess what is the format (the RFC support 3), it will
@@ -347,6 +365,7 @@ class UebiMiau_core {
 	*/
 
 	function build_complex_body($ctype,$body) {
+
 		global $sid,$lid,$ix,$folder;
 
 		$Rtype = trim(substr($ctype,strpos($ctype,"type=")+5,strlen($ctype)));
@@ -407,11 +426,11 @@ class UebiMiau_core {
 
 				if($cid != "") {
 					$cid = "cid:$cid";
-					$this->_msgbody	= preg_replace("/".quotemeta($cid)."/i",$thisfile,$this->_msgbody);
+					$this->_msgbody	= preg_replace("/".preg_quote($cid)."/i",$thisfile,$this->_msgbody);
 
 				} elseif($this->displayimages) {
 					$ext = substr($thisattach["name"],-4);
-					$allowed_ext = Array(".gif",".jpg");
+					$allowed_ext = Array(".gif",".jpg",".png",".bmp");
 					if(in_array($ext,$allowed_ext)) {
 						$this->add_body("<img src=\"$thisfile\">");
 					}
@@ -428,9 +447,9 @@ class UebiMiau_core {
 	Format a plain text string into a HTML formated string
 	*/
 
-	function build_text_body($body) {
-		$body = preg_replace("/(\r\n|\n|\r)/","<BR />\\1",$this->make_link_clickable(htmlspecialchars($body)));
-		return "<font face=\"Courier New\" size=2>$body</font>";
+		function build_text_body($body) {
+		$body = preg_replace("/(\r\n|\n|\r|\n\r)/","<br>\\1",$this->make_link_clickable(htmlspecialchars($body)));
+		return "<font face=\"Courier New\" size=\"2\">$body</font>";
 	}
 
 	/**
@@ -447,7 +466,7 @@ class UebiMiau_core {
 
 	function make_link_clickable($str){
 
-		$str = eregi_replace("([[:space:]])((f|ht)tps?:\/\/[a-z0-9~#%@\&:=?+\/\.,_-]+[a-z0-9~#%@\&=?+\/_.;-]+)", "\\1<a class=autolink href=\"\\2\" target=\"_blank\">\\2</a>", $str); //http 
+	$str = eregi_replace("([[:space:]])((f|ht)tps?:\/\/[a-z0-9~#%@\&:=?+\/\.,_-]+[a-z0-9~#%@\&=?+\/_.;-]+)", "\\1<a class=autolink href=\"\\2\" target=\"_blank\">\\2</a>", $str); //http 
 		$str = eregi_replace("([[:space:]])(www\.[a-z0-9~#%@\&:=?+\/\.,_-]+[a-z0-9~#%@\&=?+\/_.;-]+)", "\\1<a class=autolink href=\"http://\\2\" target=\"_blank\">\\2</a>", $str); // www. 
 		$str = eregi_replace("([[:space:]])([_\.0-9a-z-]+@([0-9a-z][0-9a-z-]+\.)+[a-z]{2,3})","\\1<a class=autolink href=\"mailto:\\2\">\\2</a>", $str); // mail 
 
@@ -527,66 +546,79 @@ class UebiMiau_core {
 		$cdisp = $headers["content-disposition"];
 		$ctype = $headers["content-type"]; 
 
-		preg_match("/filename ?= ?(.+)/i",$cdisp,$matches);
-		$filename = preg_replace("/\"(.*)\"/","\\1",trim($matches[1]));
+		// for debug 
+		//echo "<br>CDisp: ". $cdisp . " - CType: " . $ctype;
+
+		// try to extract filename from content-disposition
+		preg_match("/filename ?= ?\"(.+)\"/i",$cdisp,$matches);
+		$filename = trim($matches[1]);
+	
+		// if the first not work, same regex without duoblequote
 		if(!$filename) {
-			preg_match("/name ?= ?(.+)/i",$ctype,$matches);
-			$filename = preg_replace("/\"(.*)\"/","\\1",trim($matches[1]));
+			preg_match("/filename ?= ?(.+)/i",$cdisp,$matches);
+        	        $filename = trim($matches[1]);
+		}
+		
+		// try to extract from content-type
+		if(!$filename) {
+			preg_match("/name ?= ?\"(.+)\"/i",$ctype,$matches);
+			$filename = trim($matches[1]);
 		}
 
 		$tenc = $headers["content-transfer-encoding"];
 
-		preg_match("/[a-z0-9]+/",$cdisp,$matches);
+		// extract content-disposition 	(ex "attachment")
+		preg_match("/[a-z0-9]+/i",$cdisp,$matches);
 		$content_disposition 	= $matches[0];
 
-		preg_match("/[a-z0-9\/-]+/",$ctype,$matches);
+		// extract content-type		(ex "text/plain" or "application/vnd.ms-excel" note the DOT)
+		preg_match("/[a-z0-9\/\.-]+/i",$ctype,$matches);	
 		$content_type 	= $matches[0];
 
 		$tmp 			= explode("/",$content_type);
 		$main_type 		= $tmp[0];
 		$sub_type		= $tmp[1];
 
-		$is_embebed = ($headers["content-id"] != "")?1:0;
+		// This set determine if an attachement is embedded (like some images) so there no download link	
+		// Note: added check for use it only for images, some clients adds id where not necessary
+		$is_embed = ($main_type == "image" && $headers["content-id"] != "")?1:0;
 
 		$body = $this->compile_body($body,$tenc,$ctype);
 
-
 		if($filename == "" && $main_type == "message") {
 			$attachheader = $this->fetch_structure($body);
 			$attachheader = $this->decode_header($attachheader["header"]);
-			$filename = $attachheader["subject"];
-			if(strlen($filename) > 94)
-				$filename = substr($filename, 0, 90).'...'.substr($filename,-90);
-			$filename .= '.eml';
+			$filename = $attachheader["subject"].".eml";
 			unset($attachheader);
 		} elseif($filename == "") {
 			$filename = uniqid("").".tmp";
 		}
 
 		$filename = preg_replace("/[.]{2,}/",".",preg_replace("'(/|\\\\)+'","_",trim($this->decode_mime_string($filename))));
-		$filename = substr($filename,-100);
-
-		$nIndex 							= count($this->_content["attachments"]);
+		$safefilename = preg_replace("/[ \t\.\W]+/", "_", $filename);
+		$nIndex 					= count($this->_content["attachments"]);
 		$temp_array["name"] 				= trim($filename);
 		$temp_array["size"] 				= strlen($body);
-		$temp_array["temp"] 				= $is_embebed;
+		$temp_array["temp"] 				= $is_embed;
 		$temp_array["content-type"] 		= strtolower(trim($content_type));
 		$temp_array["content-disposition"] 	= strtolower(trim($content_disposition));
 		$temp_array["boundary"] 			= $boundary;
 		$temp_array["part"] 				= $part;
-		$temp_array["filename"] 			= $this->user_folder."_attachments/".md5($temp_array["boundary"])."_".$temp_array["size"]."_".$temp_array["name"];
+		$temp_array["filename"] 			= $this->user_folder."_attachments/".md5($temp_array["boundary"])."_".$safefilename;
 		$temp_array["type"] 				= "mime";
 		$temp_array["index"]				= $nIndex;
 
 		$this->_save_file($temp_array["filename"],$body);
-		
+		unset($body);
 		$this->_content["attachments"][$nIndex] = $temp_array;
-		
+
 		return $temp_array;
 
 	}
 
 
+
+
 	/**
 	Compile a string following the encoded method
 	*/
