@@ -1,16 +1,18 @@
-<?
+<?php
 class UebiMiau extends UebiMiau_core {
 
 	var $_current_folder 	= "";
 	var $_sysmap			= Array(
 								"inbox" 	=> "inbox",
 								"trash" 	=> "trash",
-								"sent" 		=> "sent");
+								"sent" 	=> "sent",
+								"spam" 	=> "spam");
 
 	var $_system_folders 	= Array(
 								"inbox",
 								"trash",
-								"sent");
+								"sent",
+								"spam");
 	
 	var $_boxes				= Array();
 	var $CRLF				= "\r\n";
