@@ -1,4 +1,4 @@
-<?
+<?php
 /************************************************************************
 UebiMiau is a GPL'ed software developed by 
 
@@ -7,6 +7,14 @@ UebiMiau is a GPL'ed software developed by
 
 Fell free to contact, send donations or anything to me :-)
 So Paulo - Brasil
+**********************************************
+
+Recoded to UebiMiau Version 3.0 by Dave Rodgers 
+Dec 2006
+http://www.manvel.net
+Email: Davenmanvel@inbox.com
+Feel free to contact me, send donations or anything to me as well...
+
 *************************************************************************/
 
 @set_time_limit(0);
@@ -85,10 +93,12 @@ if(isset($f_pass) && strlen($f_pass) > 0) {
 		//	$domain = $regs[2];
 		//	if($one_for_all_login_type != "") $f_user = eregi_replace("%user%",$f_user,eregi_replace("%domain%",$domain,$one_for_all_login_type));
 		//}
+		//DirectAdmin
 		$f_user = $f_email; //added by DA
 		$f_server = $default_mail_server;
 
                 //Added by DA
+		//DirectAdmin
                 if (!ereg("@", $f_email))
                 {
                 $domain = "localhost";
@@ -178,8 +188,8 @@ $nocache = "
 
 // Sort rules
 
-if(!isset($sortby) || !ereg("(subject|fromname|date|size)",$sortby)) {
-	if(array_key_exists("sort-by",$prefs) && ereg("(subject|fromname|date|size)",$prefs["sort-by"]))
+if(!isset($sortby) || !ereg("(fromname|subject|date|size)",$sortby)) {
+	if(array_key_exists("sort-by",$prefs) && ereg("(fromname|subject|date|size)",$prefs["sort-by"]))
 		$sortby = $prefs["sort-by"];
 	else
 		$sortby = $default_sortby;
