@@ -1,5 +1,4 @@
-<?
-
+<?php
 /************************************************************************
 UebiMiau is a GPL'ed software developed by 
 
@@ -8,6 +7,14 @@ UebiMiau is a GPL'ed software developed by
 
 Fell free to contact, send donations or anything to me :-)
 So Paulo - Brasil
+**********************************************
+
+Recoded to UebiMiau Version 3.0 by Dave Rodgers 
+Dec 2006
+http://www.manvel.net
+Email: Davenmanvel@inbox.com
+Feel free to contact me, send donations or anything to me as well...
+
 *************************************************************************/
 
 require("./inc/inc.php");
@@ -48,8 +55,22 @@ if(is_array($sess["headers"]) && file_exists($userfolder)) {
 			}
 		}
 	}
+if($prefs["empty-spam"]) {
+		if(!$UM->mail_connect()) { redirect("error.php?err=1&tid=$tid&lid=$lid"); exit; }
+		if(!$UM->mail_auth()) { redirect("badlogin.php?tid=$tid&lid=$lid&error=".urlencode($UM->mail_error_msg)); exit; }
+		$spam = $sysmap["spam"];
+		if(!is_array($sess["headers"][base64_encode($trash)])) $sess["headers"][base64_encode($trash)] = $UM->mail_list_msgs($spam);
+		$spam = $sess["headers"][base64_encode($spam)];
 
-
+		if(count($spam) > 0) {
+			for($j=0;$j<count($spam);$j++) {
+				$UM->mail_delete_msg($spam[$j],false);
+			}
+			$UM->mail_expunge();
+		}
+		$UM->mail_disconnect();
+	}
+	$SS->Kill();
 	if($prefs["empty-trash"]) {
 		if(!$UM->mail_connect()) { redirect("error.php?err=1&tid=$tid&lid=$lid"); exit; }
 		if(!$UM->mail_auth()) { redirect("badlogin.php?tid=$tid&lid=$lid&error=".urlencode($UM->mail_error_msg)); exit; }
@@ -63,6 +84,7 @@ if(is_array($sess["headers"]) && file_exists($userfolder)) {
 			}
 			$UM->mail_expunge();
 		}
+
 		$UM->mail_disconnect();
 	}
 	$SS->Kill();
