@@ -1,4 +1,4 @@
-<?
+<?php
 
 /************************************************************************
 UebiMiau is a GPL'ed software developed by 
@@ -8,6 +8,14 @@ UebiMiau is a GPL'ed software developed by
 
 Fell free to contact, send donations or anything to me :-)
 So Paulo - Brasil
+**********************************************
+
+Recoded to UebiMiau Version 3.0 by Dave Rodgers 
+Dec 2006
+http://www.manvel.net
+Email: Davenmanvel@inbox.com
+Feel free to contact me, send donations or anything to me as well...
+
 *************************************************************************/
 
 require("./inc/inc.php");
@@ -209,7 +217,7 @@ if(isset($tipo) && $tipo == "send") {
 		mywin = 'upload.php';
 		if (rem != null) mywin += '?rem='+rem+'&tid=$tid&lid=$lid';
 		else mywin += '?tid=$tid&lid=$lid';
-		window.open(mywin,'Upload','width=300,height=50,scrollbars=0,menubar=0,status=0'); 
+		window.open(mywin,'Upload','width=300,height=150,scrollbars=0,menubar=0,status=0'); 
 	}
 
 	function doupload() {
@@ -256,14 +264,24 @@ if(isset($tipo) && $tipo == "send") {
 			frm.submit();
 		}
 	}
-	
+	function envspell() {
+		error_msg = new Array();
+		frm = document.composeForm;
+
+		if(bIs_html) frm.body.value = GetHtml();
+		frm.tipo.value = 'spell';
+		frm.submit();
+	}
+
+
+
 	function newmsg() { location = 'newmsg.php?pag=$pag&folder=".urlencode($folder)."&tid=$tid&lid=$lid'; }
 	function folderlist() { location = 'folders.php?folder=".urlencode($folder)."&tid=$tid&lid=$lid'}
 	function goend() { location = 'logout.php?tid=$tid&lid=$lid'; }
 	function goinbox() { location = 'messages.php?folder=inbox&tid=$tid&lid=$lid'; }
 	function emptytrash() {	location = 'folders.php?empty=trash&folder=".urlencode($folder)."&goback=true&tid=$tid&lid=$lid';}
 	function search() {	location = 'search.php?folder=".urlencode($folder)."&tid=$tid&lid=$lid';}
-	function addrpopup() {	mywin = window.open('quick_address.php?tid=$tid&lid=$lid','AddressBook','width=480,height=220,top=200,left=200'); }
+	function addrpopup() {	mywin = window.open('quick_address.php?tid=$tid&lid=$lid','AddressBook','width=600,height=300,top=200,left=200,scrollbars=1,resizable'); }
 	function addresses() { location = 'addressbook.php?tid=$tid&lid=$lid'; }
 	function prefs() { location = 'preferences.php?tid=$tid&lid=$lid'; }
 	function AddAddress(strType,strAddress) {
@@ -446,7 +464,7 @@ $tmpbody";
 			$body = "
 <br>
 <BLOCKQUOTE dir=ltr style=\"PADDING-RIGHT: 0px; PADDING-LEFT: 5px; MARGIN-LEFT: 5px; BORDER-LEFT: #000000 2px solid; MARGIN-RIGHT: 0px\">
-  <DIV style=\"FONT: 10pt arial\">
+  <DIV style=\"FONT: 8pt verdana,arial\">
   $body
   </DIV>
 </BLOCKQUOTE>
@@ -537,6 +555,57 @@ $tmpbody";
 	$smarty->display("$selected_theme/newmsg.htm");
 
 }
+if($tipo == "spell") {
+
+	echo '<center>';
+	echo '<table cellspacing=2 cellpadding=0 border=0 align=center width="700">';
+	echo '<font face=arial size=3>';
+	echo 'Spell checking: <br>';
+	echo $body;
+	echo '<br>';
+	echo '<hr>';
+
+	$tmpdir = 'c:/aspell';
+	$tmpfile = tempnam($tmpdir, "spell");
+
+	//Probably should do an insanity check but for now this will do.
+	//if (file_exists($tmpfile))
+	$fp = fopen ("$tmpfile", "w"); 
+
+	fputs ($fp, "$body");
+
+	fclose($fp);
+
+	$mstrng = shell_exec('C:\aspell\aspell.exe pipe < '.$tmpfile);
+
+	$deletefile = @unlink($tmpfile);
+
+	$mstrng = ereg_replace( "Content-type: text/html", " ", $mstrng );
+	$list = explode("&", $mstrng);
+	$count = count($list);
+
+	if ($count > 1) {
+		for ($loop=1;$loop<$count;$loop++) {
+			$suggest = explode(",", $list[$loop]);
+			$suggestcount = count($suggest);
+			for ($loop2=0;$loop2<$suggestcount;$loop2++) {
+				if ($loop2 == 0) {
+					$tmpsuggest = explode(" ", $suggest[$loop2]);
+					echo 'Incorrect word: <b>'.$tmpsuggest[1].'</b><br><br>';
+					echo 'Possible suggestions: '.$tmpsuggest[4].' ';
+					} else {
+						$suggest[$loop2] = trim($suggest[$loop2]);
+						echo ' '.$suggest[$loop2].' ';
+						}
+					}
+				echo '<br>';
+				echo '<hr>';
+				}
+	} else { echo 'Spell Check Complete. No spelling errors found.'; }
+	echo '</font>';
+	echo '</table>';
+	echo '</center>';
+}
 
 ?>
 
